<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>CategoryDialog</name>
    <message>
        <location filename="../../category_dialog.ui" line="14"/>
        <source>Choose Category</source>
        <translation>Choisir une catégorie</translation>
    </message>
    <message>
        <location filename="../../category_dialog.ui" line="26"/>
        <source>&amp;Category</source>
        <translation>&amp;Catégorie</translation>
    </message>
</context>
<context>
    <name>ConverterWindow</name>
    <message>
        <location filename="../../converter_window.ui" line="14"/>
        <source>Convert Units</source>
        <translation>Convertir les unités</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="22"/>
        <source>Amo&amp;unt</source>
        <translation>Qua&amp;ntité</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="79"/>
        <source>kg/l</source>
        <translation>kg/l</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="86"/>
        <source>Con&amp;verted</source>
        <translation>Con&amp;verti</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="102"/>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="104"/>
        <source>rolled oats</source>
        <translation>flocons d&apos;avoine</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="105"/>
        <source>bread crumbs</source>
        <translation>chapelure</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="106"/>
        <source>desiccated coconut</source>
        <translation>noix de coco séchée</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="107"/>
        <source>cornflour</source>
        <translation>farine de maïs</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="108"/>
        <source>cocoa</source>
        <translation>cacao</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="109"/>
        <source>ground almonds</source>
        <translation>poudre d&apos;amande</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="110"/>
        <source>shredded suet</source>
        <translation>suif râpé</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="111"/>
        <source>sugar</source>
        <translation>sucre</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="112"/>
        <source>rice</source>
        <translation>riz</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="113"/>
        <source>haricots</source>
        <translation>haricots</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="114"/>
        <source>lentils</source>
        <translation>lentilles</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="115"/>
        <source>barley</source>
        <translation>orge</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="116"/>
        <source>peas</source>
        <translation>pois</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="117"/>
        <source>sultana</source>
        <translation>sultane</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="118"/>
        <source>tapioca</source>
        <translation>tapioca</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="119"/>
        <source>ground rice</source>
        <translation>farine de riz</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="120"/>
        <source>currants</source>
        <translation>groseilles</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="121"/>
        <source>semolina</source>
        <translation>semoule</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="122"/>
        <source>raisins</source>
        <translation>raisins secs</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="123"/>
        <source>custard powder</source>
        <translation>crème anglaise</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="124"/>
        <source>flour</source>
        <translation>farine</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="125"/>
        <source>milk</source>
        <translation>lait</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="126"/>
        <source>icing sugar</source>
        <translation>sucre glace</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="127"/>
        <source>Custom</source>
        <translation>sur mesure</translation>
    </message>
</context>
<context>
    <name>EditDialog</name>
    <message>
        <location filename="../../edit_dialog.ui" line="14"/>
        <source>Edit Recipe</source>
        <translation>Modifier la recette</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="28"/>
        <source>&amp;General</source>
        <translation>&amp;Général</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="36"/>
        <location filename="../../edit_dialog.ui" line="570"/>
        <source>&amp;Title:</source>
        <translation>&amp;Titre</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="49"/>
        <location filename="../../edit_dialog.ui" line="717"/>
        <source>title</source>
        <translation>titre
</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="56"/>
        <source>&amp;Categories:</source>
        <translation>&amp;Catégories</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="66"/>
        <source>category1, category2, ...</source>
        <translation>catégorie 1, catégorie 2 ...</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="73"/>
        <source>&amp;Yield:</source>
        <translation>&amp;Couverts</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="98"/>
        <source>servings</source>
        <translation>couverts</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="123"/>
        <source>&amp;Ingredients</source>
        <translation>&amp;Ingrédients</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="146"/>
        <source>Add &amp;Group</source>
        <translation>Ajouter &amp;groupe</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="153"/>
        <source>Add &amp;Ingredient</source>
        <translation>Ajouter ingrédient</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="160"/>
        <location filename="../../edit_dialog.ui" line="654"/>
        <source>&amp;Remove</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="167"/>
        <location filename="../../edit_dialog.ui" line="661"/>
        <source>&amp;Up</source>
        <translation>&amp;Haut</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="178"/>
        <location filename="../../edit_dialog.ui" line="672"/>
        <source>&amp;Down</source>
        <translation>&amp;Bas</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="189"/>
        <source>U&amp;nit Converter</source>
        <translation>Con&amp;vertisseur</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="220"/>
        <source>I&amp;ngredient</source>
        <translation>I&amp;ngrédient</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="226"/>
        <source>A&amp;mount:</source>
        <translation>Q&amp;uantité</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="239"/>
        <source>fraction</source>
        <translation>fraction</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="244"/>
        <source>float</source>
        <translation>décimal</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="284"/>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="301"/>
        <source>/</source>
        <translation>/</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="359"/>
        <source>Uni&amp;t:</source>
        <translation>Uni&amp;té</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="370"/>
        <source>per serving</source>
        <translation>par couvert</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="375"/>
        <source>small</source>
        <translation>petit</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="380"/>
        <source>medium</source>
        <translation>moyen</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="385"/>
        <source>large</source>
        <translation>large</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="390"/>
        <source>can</source>
        <translation>canette</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="395"/>
        <source>package</source>
        <translation>packet</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="400"/>
        <source>pinch</source>
        <translation>pincée</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="405"/>
        <source>drop</source>
        <translation>goutte</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="410"/>
        <source>dash</source>
        <translation>soupçon</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="415"/>
        <source>carton</source>
        <translation>carton</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="420"/>
        <source>bunch</source>
        <translation>bouquet</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="425"/>
        <source>slice</source>
        <translation>tranche</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="430"/>
        <source>each</source>
        <translation>chaque</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="435"/>
        <source>teaspoon</source>
        <translation>cc</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="440"/>
        <source>tablespoon</source>
        <translation>cs</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="445"/>
        <source>fluid ounce</source>
        <translation>once liquide</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="450"/>
        <source>cup</source>
        <translation>tasse</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="455"/>
        <source>pint</source>
        <translation>pinte</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="460"/>
        <source>quart</source>
        <translation>quart</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="465"/>
        <source>gallon</source>
        <translation>gallon</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="470"/>
        <source>ounce</source>
        <translation>once</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="475"/>
        <source>pound</source>
        <translation>livre</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="480"/>
        <source>milliliter</source>
        <translation>ml</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="485"/>
        <source>cubic cm</source>
        <translation>cc</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="490"/>
        <source>centiliter</source>
        <translation>cl</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="495"/>
        <source>deciliter</source>
        <translation>dl</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="500"/>
        <source>liter</source>
        <translation>l</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="505"/>
        <source>milligram</source>
        <translation>mg</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="510"/>
        <source>centigram</source>
        <translation>cg</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="515"/>
        <source>decigram</source>
        <translation>dg</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="520"/>
        <source>gram</source>
        <translation>g</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="525"/>
        <source>kilogram</source>
        <translation>kg</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="538"/>
        <source>Na&amp;me:</source>
        <translation>No&amp;m</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="548"/>
        <location filename="../../edit_dialog.cc" line="220"/>
        <source>ingredient</source>
        <translation>ingrédient</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="562"/>
        <source>Ingredient &amp;Section</source>
        <translation>Ingrédient &amp;Section</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="609"/>
        <source>Select section or ingredient</source>
        <translation>Choisir la section ou l&apos;ingrédient</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="624"/>
        <source>In&amp;structions</source>
        <translation>In&amp;structions</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="647"/>
        <source>&amp;Add Group</source>
        <translation>&amp;Ajouter groupe</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="693"/>
        <source>Instruction</source>
        <translation>Instruction</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="701"/>
        <source>&amp;Title</source>
        <translation>&amp;Titre</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="755"/>
        <source>&amp;Ok</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="765"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.cc" line="242"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
</context>
<context>
    <name>ExportDialog</name>
    <message>
        <location filename="../../export_dialog.ui" line="14"/>
        <source>Export MealMaster Recipes</source>
        <translation>Exporter des recettes MealMaster</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="26"/>
        <source>En&amp;coding</source>
        <translation>En&amp;codage</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="46"/>
        <source>ISO-8859-1</source>
        <translation>ISO-8859-1</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="51"/>
        <source>ISO-8859-15</source>
        <translation>ISO-8859-15</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="56"/>
        <source>CP850</source>
        <translation>CP850</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="61"/>
        <source>UTF-8</source>
        <translation>UTF-8</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="66"/>
        <source>US-ASCII</source>
        <translation>US-ASCII</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="74"/>
        <source>Error Fi&amp;le</source>
        <translation>Fi&amp;chier d&apos;erreur</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="92"/>
        <source>/tmp/errors.mmf</source>
        <translation>/tmp/errors.mmf</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="102"/>
        <source>&amp;Select error file</source>
        <translation>&amp;Sélectionner le fichier d&apos;erreurs</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="141"/>
        <source>Proceed with selection of output file</source>
        <translation>Sélectionner le fichier à enregistrer</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="148"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="../../export_dialog.cc" line="42"/>
        <source>Select Error File</source>
        <translation>Sélectionner le fichier d&apos;erreurs</translation>
    </message>
    <message>
        <location filename="../../export_dialog.cc" line="42"/>
        <source>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;All files (*)</source>
        <translation>MealMaster (*.mm *.MM *.mmf *.MMF);;Texte (*.txt *.TXT);;Tous les fichiers (*)</translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <location filename="../../import_dialog.ui" line="14"/>
        <source>Import MealMaster Recipes</source>
        <translation>Importer des recettes MealMaster</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="26"/>
        <source>Encodin&amp;g</source>
        <translation>Encodag&amp;e</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="46"/>
        <source>ISO-8859-1</source>
        <translation>ISO-8859-1</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="51"/>
        <source>ISO-8859-15</source>
        <translation>ISO-8859-15</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="56"/>
        <source>CP850</source>
        <translation>CP850</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="61"/>
        <source>UTF-8</source>
        <translation>UTF-8</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="66"/>
        <source>US-ASCII</source>
        <translation>US-ASCII</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="74"/>
        <source>Error Fi&amp;le</source>
        <translation>Fi&amp;chier d&apos;erreur</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="92"/>
        <source>/tmp/errors.mmf</source>
        <translation>/tmp/errors.mmf</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="102"/>
        <source>&amp;Select error file</source>
        <translation>&amp;Sélectionner le fichier d&apos;erreurs</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="141"/>
        <source>Pr&amp;oceed with selection of recipes</source>
        <translation>Sé&amp;lectionner le fichier à enregistrer</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="148"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>errors.mmf</source>
        <translation type="vanished">errors.mmf</translation>
    </message>
    <message>
        <location filename="../../import_dialog.cc" line="42"/>
        <source>Select Error File</source>
        <translation>Sélectionner le fichier d&apos;erreurs</translation>
    </message>
    <message>
        <location filename="../../import_dialog.cc" line="42"/>
        <source>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;All files (*)</source>
        <translation>MealMaster (*.mm *.MM *.mmf *.MMF);;Texte (*.txt *.TXT);;Tous les fichiers (*)</translation>
    </message>
</context>
<context>
    <name>IngredientModel</name>
    <message>
        <location filename="../../ingredient_model.cc" line="43"/>
        <source>amount</source>
        <translation>quantité</translation>
    </message>
    <message>
        <location filename="../../ingredient_model.cc" line="45"/>
        <source>unit</source>
        <translation>unité</translation>
    </message>
    <message>
        <location filename="../../ingredient_model.cc" line="47"/>
        <source>ingredient</source>
        <translation>ingrédient</translation>
    </message>
    <message>
        <location filename="../../ingredient_model.cc" line="76"/>
        <location filename="../../ingredient_model.cc" line="215"/>
        <source>&lt;Main&gt;</source>
        <translation>&lt;Principal&gt;</translation>
    </message>
</context>
<context>
    <name>InstructionsModel</name>
    <message>
        <location filename="../../instructions_model.cc" line="52"/>
        <location filename="../../instructions_model.cc" line="62"/>
        <source>&lt;Main&gt;</source>
        <translation>&lt;Principal&gt;</translation>
    </message>
    <message>
        <location filename="../../instructions_model.cc" line="78"/>
        <source>section</source>
        <translation>section</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../main_window.ui" line="14"/>
        <source>AnyMeal</source>
        <translation>AnyMeal</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="27"/>
        <source>&amp;Show all recipes</source>
        <translation>&amp;Afficher toutes les recettes</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="34"/>
        <source>&amp;Title</source>
        <translation>&amp;Titre</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="44"/>
        <source>Search for title text.</source>
        <translation>Rechercher par titre</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="54"/>
        <location filename="../../main_window.ui" line="97"/>
        <source>w</source>
        <translation>avec</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="64"/>
        <location filename="../../main_window.ui" line="110"/>
        <source>w/o</source>
        <translation>sans</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="74"/>
        <source>&amp;Category</source>
        <translation>&amp;Catégorie</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="84"/>
        <source>Search for categories.</source>
        <translation>Recherche par catégorie</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="94"/>
        <source>Search for recipes with ingredient.</source>
        <translation>Rechercher les recettes avec un ingrédient</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="107"/>
        <source>Search for recipes without ingredient.</source>
        <translation>Rechercher les recettes sans un ingrédient</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="120"/>
        <source>&amp;Ingredient</source>
        <translation>&amp;Ingrédient</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="130"/>
        <source>Specify the ingredient.</source>
        <translation>Préciser l&apos;ingrédient</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="137"/>
        <source>&amp;Search</source>
        <translation>&amp;Rechercher</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="201"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="214"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="221"/>
        <source>Edit</source>
        <translation>Edition</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="236"/>
        <source>Tool Bar</source>
        <translation>Barre d&apos;outils</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="264"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="267"/>
        <source>Exit application</source>
        <translation>Quitter l&apos;application</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="270"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="279"/>
        <source>&amp;Import recipes</source>
        <translation>&amp;Importer des recettes</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="282"/>
        <source>Read MealMaster recipes from files</source>
        <translation>Ouvrir des recettes MealMaster</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="285"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="294"/>
        <source>Print p&amp;review</source>
        <translation>Aperçu avant i&amp;mpression</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="297"/>
        <source>Print preview of current recipe</source>
        <translation>Aperçu de la recette courante avant impression</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="300"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="309"/>
        <source>&amp;Print recipe</source>
        <translation>&amp;Imprimer la recette</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="312"/>
        <source>Print current recipe</source>
        <translation>Imprimer la recette courante</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="315"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="324"/>
        <source>A&amp;bout AnyMeal</source>
        <translation>A &amp;propos d&apos;Anymeal</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="327"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="336"/>
        <source>&amp;Delete recipes</source>
        <translation>&amp;Supprimer les recettes</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="339"/>
        <source>Delete selected recipes</source>
        <translation>Supprimer les recettes sélectionnées</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="342"/>
        <source>Del</source>
        <translation>Supp.</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="351"/>
        <source>Exp&amp;ort recipes</source>
        <translation>Exp&amp;orter des recettes</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="354"/>
        <source>Write MealMaster recipes to file</source>
        <translation>Enregistrer des recettes MealMaster</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="357"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="366"/>
        <source>&amp;Edit Recipe</source>
        <translation>&amp;Modifier la recette</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="369"/>
        <source>Edit current recipe</source>
        <translation>Modifier la recette courante</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="372"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="381"/>
        <source>Collect &amp;Garbage</source>
        <translation>Ramasser les Ord&amp;ures</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="384"/>
        <source>Delete unused categories and ingredients</source>
        <translation>Supprimer les catégories et ingrédients inutilisés</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="387"/>
        <source>Ctrl+G</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="396"/>
        <source>Add &amp;to Category</source>
        <translation>Ajou&amp;ter à une catégorie</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="399"/>
        <source>Add selected recipes to a category</source>
        <translation>Ajouter à une ca&amp;tégorie les recettes sélectionnées</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="402"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="411"/>
        <source>&amp;Remove from Category</source>
        <translation>&amp;Retirer d&apos;une catégorie</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="414"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="423"/>
        <source>Open Co&amp;nverter Window</source>
        <translation>Ouvrir le co&amp;nvertisseur</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="426"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="453"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="435"/>
        <source>Remove duplicates</source>
        <translation>Supprimer les doublons</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="438"/>
        <source>Remove duplicates in selected recipes</source>
        <translation>Supprimer les doublons dans les recettes sélectionnées</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="447"/>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="450"/>
        <source>New recipe</source>
        <translation>Nouvelle recette</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="92"/>
        <source>Error Opening Database</source>
        <translation>Erreur d&apos;ouverture de la base de données</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="98"/>
        <source>Showing %1 recipes ...</source>
        <translation>Affiche %1 recettes ...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="108"/>
        <source>Import MealMaster Files</source>
        <translation>Importer des fichiers MealMaster</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="108"/>
        <location filename="../../main_window.cc" line="438"/>
        <source>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;All files (*)</source>
        <translation>MealMaster (*.mm *.MM *.mmf *.MMF);;Texte (*.txt *.TXT);;Tous les fichiers (*)</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="114"/>
        <source>Importing files ...</source>
        <translation>Importation en cours</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="114"/>
        <location filename="../../main_window.cc" line="445"/>
        <location filename="../../main_window.cc" line="546"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="123"/>
        <source>%1 imported and %2 failed ...</source>
        <translation>%1 importées et %2 échouées</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="137"/>
        <source>Rejected recipe: </source>
        <translation>Recette rejetée:</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="142"/>
        <location filename="../../main_window.cc" line="469"/>
        <location filename="../../main_window.cc" line="477"/>
        <source>Error writing to file </source>
        <translation>Erreur d&apos;écriture</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="163"/>
        <source>Recipes Imported</source>
        <translation>Recettes importées</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="163"/>
        <source>%1 imported and %2 failed.</source>
        <translation>%1 importées et %2 échouées</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="167"/>
        <source>Error While Importing</source>
        <translation>Erreur lors de l&apos;import</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="178"/>
        <source>Edit current recipe, a copy of the recipe, a new recipe, or cancel?</source>
        <translation>Modifier la recette courante, créer une copie, une nouvelle recette ou annuler?</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="179"/>
        <source>&amp;Edit Current</source>
        <translation>Modifier la r&amp;ecette courante</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="180"/>
        <source>Edit C&amp;opy</source>
        <translation>Créer une c&amp;opie</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="181"/>
        <source>Edit &amp;New</source>
        <translation>Créer une &amp;nouvelle recette</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="182"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="250"/>
        <source>Error While Updating Recipe</source>
        <translation>Erreur lors de la mise à jour</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="275"/>
        <source>Error Adding Recipes to Category</source>
        <translation>Erreur lors de l&apos;ajout de recettes à une catégorie</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="301"/>
        <source>Error Removing Recipes from Category</source>
        <translation>Erreur lors du retrait de recettes d&apos;une catégorie</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="320"/>
        <source>Error Collecting Garbage</source>
        <translation>Erreur lors de la collecte des déchets</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="329"/>
        <source>About AnyMeal %1</source>
        <translation>A propos d&apos;Anymeal %1</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="374"/>
        <source>Error Filtering Recipes</source>
        <translation>Erreur lors du filtrage des recettes</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="388"/>
        <source>Error Resetting Selection</source>
        <translation>Erreur de réinitialisation de la sélection</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="408"/>
        <source>Error fetching recipe</source>
        <translation>Erreur lors de la recherche</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="438"/>
        <source>Export MealMaster File</source>
        <translation>Exporter un fichier MealMaster</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="445"/>
        <source>Exporting recipes ...</source>
        <translation>Exportation en cours</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="464"/>
        <source>Failed recipe: </source>
        <translation>Recette ratée:</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="480"/>
        <source>%1 exported and %2 failed ...</source>
        <translation>%1 exportées et %2 échouées</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="483"/>
        <source>Recipes Exported</source>
        <translation>Recettes exportées</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="483"/>
        <source>%1 exported and %2 failed.</source>
        <translation>%1 exportées et %2 échouées</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="487"/>
        <source>Error While Exporting</source>
        <translation>Erreur lors de l&apos;export</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="495"/>
        <source>Delete Recipes</source>
        <translation>Supprimer les recettes</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="495"/>
        <source>Do you want to delete the selected recipes?</source>
        <translation>Voulez-vous supprimer les recettes sélectionnées?</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="514"/>
        <source>Error Deleting Recipes</source>
        <translation>Erreur lors de la suppression</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="546"/>
        <source>Detecting duplicates ...</source>
        <translation>Détection des doublons...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="549"/>
        <source>Found %1 duplicates ...</source>
        <translation>J&apos;ai trouvé %1 doublons...</translation>
    </message>
</context>
<context>
    <name>recipe</name>
    <message>
        <location filename="../../html.cc" line="183"/>
        <source>Categories</source>
        <translation>Catégories</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="192"/>
        <source>Yield</source>
        <translation>Couverts</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="196"/>
        <source>Ingredients</source>
        <translation>Ingrédients</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="199"/>
        <source>amount</source>
        <translation>quantité</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="200"/>
        <source>unit</source>
        <translation>unité</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="201"/>
        <source>ingredient</source>
        <translation>ingrédient</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="221"/>
        <source>Instructions</source>
        <translation>instructions</translation>
    </message>
</context>
<context>
    <name>units</name>
    <message>
        <location filename="../../html.cc" line="60"/>
        <source>per serving</source>
        <translation>par couvert</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="61"/>
        <source>small</source>
        <translation>petit</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="62"/>
        <source>medium</source>
        <translation>moyen</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="63"/>
        <source>large</source>
        <translation>grand</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="64"/>
        <source>can</source>
        <translation>canette</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="65"/>
        <source>package</source>
        <translation>paquet</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="66"/>
        <source>pinch</source>
        <translation>pincée</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="67"/>
        <source>drop</source>
        <translation>goutte</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="68"/>
        <source>dash</source>
        <translation>soupçon</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="69"/>
        <source>carton</source>
        <translation>carton</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="70"/>
        <source>bunch</source>
        <translation>bouquet</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="71"/>
        <source>slice</source>
        <translation>tranche</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="72"/>
        <source>each</source>
        <translation>chaque</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="73"/>
        <location filename="../../html.cc" line="74"/>
        <source>teaspoon</source>
        <translation>cc</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="75"/>
        <location filename="../../html.cc" line="76"/>
        <source>tablespoon</source>
        <translation>cs</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="77"/>
        <source>fluid ounce</source>
        <translation>once liquide</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="78"/>
        <source>cup</source>
        <translation>tasse</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="79"/>
        <source>pint</source>
        <translation>pinte</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="80"/>
        <source>quart</source>
        <translation>quart</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="81"/>
        <source>gallon</source>
        <translation>gallon</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="82"/>
        <source>ounce</source>
        <translation>once</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="83"/>
        <source>pound</source>
        <translation>livre</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="84"/>
        <source>milliliter</source>
        <translation>ml</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="85"/>
        <source>cubic cm</source>
        <translation>cc</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="86"/>
        <source>centiliter</source>
        <translation>cl</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="87"/>
        <source>deciliter</source>
        <translation>dl</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="88"/>
        <source>liter</source>
        <translation>l</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="89"/>
        <source>milligram</source>
        <translation>mg</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="90"/>
        <source>centigram</source>
        <translation>cg</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="91"/>
        <source>decigram</source>
        <translation>dg</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="92"/>
        <source>gram</source>
        <translation>g</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="93"/>
        <source>kilogram</source>
        <translation>kg</translation>
    </message>
</context>
</TS>
